%	function [Pesi, Outsider] = rbfpesi(Centri, Sigma, Gamma,
%	                                    DataIn, DataOut)
%
% Ricostruzione mediante una RBF di Platt.
%
% Centri	Posizione delle Gaussiane
% Sigma		Sigma delle gaussiane
% Pesi		Coefficienti della combinazione lineare
% Gamma		Costante di traslazione
% DataIn 	Punti di Input
% RbfOut 	Valori di Output
% Outsider	Vettore di flag per indicare se il dato corrispondente 
%		non pu generare un risultato attendibile. In questo caso 
%		assume il valore 1. Se tutto e' OK vale 0. E' un argomento 
%		opzionale.
% I dati devono essere organizzati per righe
% I parametri della rete sono generati da platt_rbf.

function [Pesi, Outsider] = rbfpesi(Centri, Sigma, Gamma, DataIn, DataOut)

if ~nargin, 
   help rbfpesi;
   return;
end;
if nargin < 4,
   disp('RBFPESI: Troppo pochi argomenti di input');
   return;
end;

if nargout < 2,
   OUTSIDER = 0;
else 
   OUTSIDER = 1;
end;

NumData = size(DataIn, 1);
DimIn = size(DataIn, 2);

NumCentri = size(Centri, 1);

% calcola la matrice gaussiana G.
% G e' una matrice NumData x NumCentri

if OUTSIDER,
   Outsider = ones(1, NumData);
end;

G = zeros(NumData, NumCentri);
for i = 1:NumCentri,
   if DimIn > 1, 
      dist = sum(((DataIn-ones(NumData, 1)*Centri(i,:)).^2)')';
   else
      dist = (DataIn-ones(NumData, 1)*Centri(i,:)).^2;
   end;
   if OUTSIDER,
      ind = find(dist < (3*Sigma(i).^2)); 
      Outsider(ind) = zeros(1, length(ind));
   end;
   G(:, i) = exp(-dist/Sigma(i).^2);
end;

Pesi = pinv(G)*(DataOut-Gamma);

